## Turn off meaningless jar repackaging 
%define __jar_repack 0

%global pom_version 1
%global mvn_settings -U -s mirror-settings.xml -DskipTests -P EMI,prod
%global python_version python26
%global oracle_libs_path /usr/lib64/oracle
%global oracle_jar_name ojdbc6.jar

Name: voms-admin-server
Version: 3.1.0 
Release: 1%{?dist}
Summary: The VOMS Administration service

Group:		Applications/Internet
License:    ASL 2.0
URL: https://twiki.cnaf.infn.it/twiki/bin/view/VOMS
Source:  %{name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildArch:      noarch

BuildRequires:  maven
BuildRequires:  jpackage-utils
BuildRequires:  java-1.6.0-openjdk-devel
BuildRequires:  oracle-instantclient-basic

Requires: java-1.6.0-openjdk-devel
Requires: python(abi) = 2.6 

%description
The Virtual Organization Membership Service (VOMS) is an attribute authority
which serves as central repository for VO user authorization information,
providing support for sorting users into group hierarchies, keeping track of
their roles and other attributes in order to issue trusted attribute
certificates and SAML assertions used in the Grid environment for
authorization purposes.

The VOMS Admin service is a web application providing tools for administering
the VOMS VO structure. It provides an intuitive web user interface for daily
administration tasks.

%prep
%setup -n voms-admin-server

%build
mvn %{mvn_settings} package

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
tar -C $RPM_BUILD_ROOT -xvzf target/%{name}.tar.gz

mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/voms-admin

mkdir -p $RPM_BUILD_ROOT%{_localstatedir}/log/voms-admin

# Stage oracle jar
cp `find %{oracle_libs_path} -name %{oracle_jar_name}` $RPM_BUILD_ROOT/var/lib/voms-admin/lib

%clean
rm -rf $RPM_BUILD_ROOT

%pre

## Create VOMS user if needed
getent group voms > /dev/null || groupadd -r voms
getent passwd voms > /dev/null || useradd -r -g voms \
    -d %{_sysconfdir}/voms -s /sbin/nologin -c "VOMS Server Account" voms

if [ -d "/var/lib/voms-admin/lib" ]; then
	rm -rf /var/lib/voms-admin/lib/*.jar 
fi
exit 0

%post 
/sbin/chkconfig --add voms-admin

if [ $1 -gt 1 ]; then
    if [ -e /etc/voms-admin/voms-siblings.xml ]; then
        rm -f /etc/voms-admin/voms-siblings.xml
    fi
    chown -R voms /etc/voms-admin
    chown -R voms /var/tmp/voms-admin
fi

%preun
if [ $1 = 0 ]; then
    /sbin/service voms-admin stop >/dev/null 2>&1 || :
    /sbin/chkconfig --del voms-admin
fi
exit 0

%postun
if [ $1 -gt 1 ]; then
    /sbin/service voms-admin restart 2>&1 || :
fi

%files

%defattr(-,root,root,-)

%{_initrddir}/voms-admin

%dir %{_sysconfdir}/voms-admin
%config(noreplace) %{_sysconfdir}/sysconfig/voms-admin

%config(noreplace) %{_sysconfdir}/voms-admin/voms-admin-server.logback
%config(noreplace) %{_sysconfdir}/voms-admin/voms-admin-server.properties

%{_sbindir}/*

%{_javadir}/voms-admin.jar
%{_javadir}/voms-container.jar
%{_datadir}/webapps/voms-admin.war

%{_datadir}/doc/voms-admin-server/* 
%{_datadir}/voms-admin/*
/var/lib/voms-admin/lib/*.jar
/var/lib/voms-admin/tools/*
%attr(-,voms,voms) %dir %{_localstatedir}/log/voms-admin

%changelog
* Tue Mar 19 2013 Andrea Ceccanti <andrea.ceccanti at cnaf.infn.it> - 3.1.0-1
- Fixes for the following bugs:
- [VOMS-229] - VOMSES startup script fails in restarting VOMSES web app
- [VOMS-230] - VOMS Admin service incorrectly parses truststore refresh period from configuration
- [VOMS-231] - Standalone VOMS Admin service deployment is not suitable for deployments with large number of VOs (> 10)
- New feature:
- [VOMS-235] - Allow easier search of users with pending Sign AUP requests

* Wed Jul 11 2012 Andrea Ceccanti <andrea.ceccanti at cnaf.infn.it> - 3.0.0-1
- VOMS admin now runs as a process in an embedded container 

* Fri Dec 16 2011 Andrea Ceccanti <andrea.ceccanti at cnaf.infn.it> - 2.7.0-1
- Self-managed packaging
